
package rubricapkg.dati;

/**
 * Gestisce numeri telefonici o email. 
 * E' un oggetto algebrico.
 * Rispetto al progetto, abbiamo scelto di unire in un'unica classe sia la 
 * gestione dell'indirizzo che quella del n. di telefono.   
 *
 * @author  brandizi
 */
public class Indirizzo
{
  
  /** Gestisce internamente le cose */
  private int prefInt = 0, pref = 0, num = 0;
  private String email = "";
  private int tipo;
  
  /** I tipi di indirizzo gestiti */
  public static final int TIPO_TEL = 0, TIPO_EMAIL = 1;
  
  /** Costruttore per email */
  public Indirizzo ( String email )
  {
    this.tipo = this.TIPO_TEL;
    this.email = email;
  }

  /** Costruttore per telefono */
  public Indirizzo ( int prefint, int pref, int num )
  {
    this.tipo = this.TIPO_EMAIL;
    this.prefInt = prefInt;
    this.pref = pref;
    this.num = num;
  }
  
  /** 
   * Getter  
   */
  public String getTipo () {
    return this.tipo;
  }

  /** Ritorna errore se type != TIPO_EMAIL */
  public String getEmail () throws TipoIndirizzoErratoException 
  {
    try {
      if ( this.tipo != this.TIPO_EMAIL )
        throw new TipoIndirizzoErratoException (
          "Richiesto email a un oggetto di tipo numero di telefono" );
    }
    finally {
      return this.email;
    }
  }

  /** 
   * Ritorna il n. di telefono completo 
   * Ritorna errore se type != TIPO_TEL 
   *
   */
  public String getTel () throws TipoIndirizzoErratoException 
  {
    try {
      if ( this.tipo != this.TIPO_EMAIL )
        throw new TipoIndirizzoErratoException ( 
          "Richiesto tel a un oggetto di tipo mail" );
    }
    finally {
      return "+" + prefInt + " " + pref + " " + num;
    }
  }
  
  /** 
   * Ritorna errore se type != TIPO_TEL 
   *
   */
  public int getPrefInt () throws TipoIndirizzoErratoException 
  {
    try {
      if ( this.tipo != this.TIPO_EMAIL )
        throw new TipoIndirizzoErratoException ( 
          "Richiesto tel a un oggetto di tipo mail" );
    }
    finally {
      return prefInt;
    }
  }

  /** 
   * Ritorna errore se type != TIPO_TEL 
   *
   */
  public int getPref () throws TipoIndirizzoErratoException 
  {
    try {
      if ( this.tipo != this.TIPO_EMAIL )
        throw new TipoIndirizzoErratoException ( 
          "Richiesto tel a un oggetto di tipo mail" );
    }
    finally {
      return pref;
    }
  }

  /** 
   * Ritorna errore se type != TIPO_TEL 
   *
   */
  public int getPref () throws TipoIndirizzoErratoException 
  {
    try {
      if ( this.tipo != this.TIPO_EMAIL )
        throw new TipoIndirizzoErratoException ( 
          "Richiesto tel a un oggetto di tipo mail" );
    }
    finally {
      return num;
    }
  }

  
  /** Torna una rappresentazione stringa (getEmail() oppure getTel() ) */
  public String toString ()
  {
    return tipo == TIPO_EMAIL ? getEmail () : this.getTel ();
  }
}
