/*
 * RubricaParser.java
 *
 * Created on December 28, 2002, 8:05 PM
 */

package rubricapkg.parser;

import rubricapkg.Util;

import rubricapkg.dati.*; 


/**
 * Analizza il comando "add"<P>
 * Tutti i parser di comandi ricevono sempre la stringa che c'e' dopo il nome
 * del comando. Esempio:<BR><BR>
 *
 * add Mario Rossi 10/5/88 tel +39-347-299383
 *
 * riceve "Mario Rossi 10/5/88 tel +39-347-299383"
 *
 * @author  brandizi
 */
public class AddParser extends RubricaParser
{
  
  private Persona persona = null;
  
  public AddParser ( Rubrica rubrica )
  {
    super ( rubrica );
  }
  
  /** 
   *  Esegue l'aggiunta del nominativo, dopo il parsing 
   */
  public void esegui () throws ComandoException
  {
    if (  persona == null )
      throw new ComandoException ( "Parsing di add non eseguito" );
    
    rubrica.add ( persona ); 
  }
  
  /** 
   * Analizza I dati del nominativo da inserire, li inserisce in variabili 
   * interne, in modo da poter eseguire successivamente.
   *  
   * <P>Ritorna se stesso come Comando.
   *
   */ 
  public Object parse ( String lineaComando ) throws ParserException 
  {
    persona = null;
    
    // Si aspetta: Cognome; Nome; <data>; <indirizzo>;
    // ovvero 4 item
    // 
    String tokens = Util.getTokens ( lineaComando, SEPARATORI );
    if ( tokens.length != 4 ) 
      throw new ParserException ( "Comando 'add' errato" );
    
    Data nascita = ( new DataParser () ).parse ( tokens [ 2 ] );
    Indirizzo indirizzo = ( new IndirizzoParser () ).parse ( tokens [ 3 ] );
    
    persona = new Persona ( tokens [ 0 ], tokens [ 1 ], nascita, indirizzo );
    
    return (Comando) this;
  }
  
}
