
package rubricapkg.parser;

import java.util.StringTokenizer;

/**
 * Analizza i comandi possibili per la rubrica. 
 * <P>E' il punto di accesso per analizzare una riga digitata dall'utente  
 *
 * @author  brandizi
 */
public class RubricaParser implements Parser, Comando
{
  
  /** La rubrica con cui lavorare */
  protected Rubrica rubrica;
  
  /** L'ultimo comando analizzato */
  protected Comando comando; 
  
  /** Separatori per i parametri dei comandi */
  protected static final String SEPARATORI = ";";
  
  /** Deve sempre far riferimento a una rubrica */
  public RubricaParser ( Rubrica rubrica )
  {
    this.rubrica = rubrica;
  }
  
  /** 
   *  Esegue l'ultimo comando analizzato con parse () 
   */
  public void esegui () throws ComandoException
  {
    if ( comando == null )
      throw new ComandoException ( "Nessun comando analizzato" );

    comando.esegui (); 
  }
  
  /** 
   * Analizza i comandi possibili per la rubrica; 
   * Ritorna un oggetto Comando, come tutti i parse di comandi
   *
   */ 
  public Object parse ( String lineaComando ) throws ParserException 
  {
    // Estrae il primo token, col comando e tutto il resto, da passare 
    // Agli altri parser
    // 
    String [] toks = rubricapkg.Util.getTokens ( " " );
    
    // Manco il comando, errore
    //
    if ( tokens.length == 0 ) 
      throw new ParserException ( "Nessun comando digitato" );
    
    String cmdName = tokens [ 0 ];
    // Esistono comandi senza parametri
    String params = tokens.length == 1 ? "" : tokens [ 1 ]; 
    Parser prs; 
    
    // Analizza i vari comandi possibili 
    //
    if ( "add".equalsIgnoreCase ( cmdName ) )
       prs = new AddParser ( rubrica );
    else if ( "edit".equalsIgnoreCase ( cmdName ) )
       prs = new EditParser ( rubrica );
    // ...
    else
      throw new ParserException ( "Comando " + cmdName + " non riconosciuto" );
      
    // Imposta il valore interno del comando e torna
    comando = ( Comando ) prs.parse ( params );
    return comando; 
    
  }
  
}
